﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using PTS_DLL;

namespace PanTiltDemo
{
    public partial class Form1 : Form
    {
        /// <summary>
        /// Speed 1, 3/8th PWM and FAST is not enabled
        /// </summary>
        private const UInt16 SPEED_SLOWEST = 0x13;

        /// <summary>
        /// Speed 2, 6/8th PWM and FAST is not enabled
        /// </summary>
        private const UInt16 SPEED_SLOWER = 0x17;

        /// <summary>
        /// Speed 3, 6/8th PWM and FAST is not enabled
        /// </summary>
        private const UInt16 SPEED_SLOW = 0x1F;

        /// <summary>
        /// Speed 4, 6/8th PWM and FAST is not enabled
        /// </summary>
        private const UInt16 SPEED_MEDIUM = 0x3F;

        /// <summary>
        /// Speed 5, 100% PWM but FAST is not enabled
        /// </summary>
        private const UInt16 SPEED_FASTER = 0x7F;

        /// <summary>
        /// Speed 6, 100% PWM and FAST is enabled
        /// </summary>
        private const UInt16 SPEED_FASTEST = 0x80;
        private Controllers Ctrls = new Controllers();

        public Form1()
        {
            InitializeComponent();
            Ctrls.RebuildCtrlList();
        }

        private void timer1_Tick(object sender, EventArgs e)
        {
            lblControllers.Text = Ctrls.CtrlList.Count.ToString();

        }

        private void btnStop_Click(object sender, EventArgs e)
        {
            if (Ctrls.CtrlList.Count > 0)
            {
                Ctrls.CtrlList[0].Move(Controller.Direction.STOP, SPEED_FASTER, SPEED_FASTER, false);
            }
        }

        private void btnUp_Click(object sender, EventArgs e)
        {
            if (Ctrls.CtrlList.Count > 0)
            {
                Ctrls.CtrlList[0].Move(Controller.Direction.UP, SPEED_FASTER, SPEED_FASTER, cbxFast.Checked);
            }
        }

        private void btnLeft_Click(object sender, EventArgs e)
        {
            if (Ctrls.CtrlList.Count > 0)
            {
                Ctrls.CtrlList[0].Move(Controller.Direction.LEFT, SPEED_FASTER, SPEED_FASTER, cbxFast.Checked);
            }
        }

        private void btnDown_Click(object sender, EventArgs e)
        {
            if (Ctrls.CtrlList.Count > 0)
            {
                Ctrls.CtrlList[0].Move(Controller.Direction.DOWN, SPEED_FASTER, SPEED_FASTER, cbxFast.Checked);
            }
        }

        private void btnRight_Click(object sender, EventArgs e)
        {
            if (Ctrls.CtrlList.Count > 0)
            {
                Ctrls.CtrlList[0].Move(Controller.Direction.RIGHT, SPEED_FASTER, SPEED_FASTER, cbxFast.Checked);
            }
        }

        private void btnScanForControllers_Click(object sender, EventArgs e)
        {
            Ctrls.RebuildCtrlList();
            if (Ctrls.CtrlList.Count > 0)
            {
                lblSN.Text = Ctrls.CtrlList[0].Identifier;
                gbLANC.Enabled = (Ctrls.CtrlList[0].Caps.LANC == 1);
                cbxFast.Enabled = true;
                btnStop.Enabled = true;
                btnUp.Enabled = true;
                btnLeft.Enabled = true;
                btnDown.Enabled = true;
                btnRight.Enabled = true;
            }
            else
            {
                lblSN.Text = "";
                gbLANC.Enabled = false;
                cbxFast.Enabled = false;
                btnStop.Enabled = false;
                btnUp.Enabled = false;
                btnLeft.Enabled = false;
                btnDown.Enabled = false;
                btnRight.Enabled = false;
            }
        }

        private void cmbLANC_DropDownClosed(object sender, EventArgs e)
        {
            switch (cmbLANC.SelectedIndex)
            {
                case -1: break;
                case 0: nudOne.Value = 0x28; nudTwo.Value = 0x35; break;
                case 1: nudOne.Value = 0x28; nudTwo.Value = 0x37; break;
                case 2: nudOne.Value = 0x28; nudTwo.Value = 0x41; break;
                case 3: nudOne.Value = 0x28; nudTwo.Value = 0x45; break;
                case 4: nudOne.Value = 0x28; nudTwo.Value = 0x47; break;
                case 5: nudOne.Value = 0x18; nudTwo.Value = 0x33; break;
                case 6: nudOne.Value = 0x1E; nudTwo.Value = 0x5E; break;
                default: break;
            }

        }

        private void btnSendOnce_Click(object sender, EventArgs e)
        {
            if (Ctrls.CtrlList.Count > 0)
            {
                Ctrls.CtrlList[0].SendLANC_Once((byte)nudOne.Value, (byte)nudTwo.Value, 0, 0, 0, 0, 0, 0);
            }
        }

        private void btnSendContinuous_Click(object sender, EventArgs e)
        {
            if (Ctrls.CtrlList.Count > 0)
            {
                Ctrls.CtrlList[0].SendLANC_Continuous((byte)nudOne.Value, (byte)nudTwo.Value, 0, 0, 0, 0, 0, 0);
            }
        }

        private void btnEnquiry_Click(object sender, EventArgs e)
        {
            if (Ctrls.CtrlList.Count > 0)
            {
                byte Byte0, Byte1, Byte2, Byte3, Byte4, Byte5, Byte6, Byte7;

                Ctrls.CtrlList[0].EnquiryLANC(out Byte0, out Byte1, out Byte2, out Byte3, out Byte4, out Byte5, out Byte6, out Byte7);

                lblLANC_RxData.Text = Byte0.ToString("X2") + " " + Byte1.ToString("X2") + " " + Byte2.ToString("X2") + " " + Byte3.ToString("X2") + " " +
                    Byte4.ToString("X2") + " " + Byte5.ToString("X2") + " " + Byte6.ToString("X2") + " " + Byte7.ToString("X2");
            }
        }

        private void btnStopSending_Click(object sender, EventArgs e)
        {
            if (Ctrls.CtrlList.Count > 0)
            {
                Ctrls.CtrlList[0].StopLANC();
            }
        }

        private void btnPowerOn_Click(object sender, EventArgs e)
        {
            if (Ctrls.CtrlList.Count > 0)
            {
                Ctrls.CtrlList[0].PowerOn();
            }
        }
    }
}
